/**
 * 企业经营数据相关 
 * 作者:lxm
 * 说明： 首页经营数据   经营数据补充
 * 备注:  填报的经营数据在  填报逻辑 里
 */

import moment = require("moment");
import { findBusinessDataByUsccAndYear } from "../../data/enterprise/businessdata";


/**
 * 获取经营数据
 * @param uscc 企业统一信用代码
 */
export async function getBusinessData(uscc:string) {
    let lastYear = moment().subtract(1, 'years').year();
    let thisYear = new Date().getFullYear();

    let thisYearData = await findBusinessDataByUsccAndYear(uscc, thisYear);
    let lastYearData = await findBusinessDataByUsccAndYear(uscc, lastYear);

    let thisYearBusinessData = countBusinessData(thisYearData);
    let lastYearBusinessData = countBusinessData(lastYearData);

    let result = {
        lastYearBI:lastYearBusinessData.BI,
        lastYearRD:lastYearBusinessData.RD,
        lastYearTXP:lastYearBusinessData.TXP,
        yearTotalBI:thisYearBusinessData.BI,
        yearTotalRD:thisYearBusinessData.RD,
        yearTotalTXP:thisYearBusinessData.TXP
    };
    
    for (let key in result) {
        result[key].notReported = !result[key].count;
    }

    return result;
}

function countBusinessData(dataList) {
    let countRD = 0;
    let countBI = 0;
    let countTXP = 0;

    dataList.forEach(info => {
        countBI += info.BI;
        countRD += info.RD;
        countTXP += info.TXP;
    });

    return {
        RD:countUnitData(countRD), 
        BI:countUnitData(countBI), 
        TXP:countUnitData(countTXP),
    }
}

/**
 * 获取格式  将金额数据转换为金额加单位
 * 单位为：元  万元  根据长度自动转换  
 * 超过千万 单位为万 否则单位为元
 * @param data 
 * @returns 
 */
function countUnitData(data:number) {
    if (!data) return {unit:"元", count:0};
    if (data/10000000 < 10) {
        return {
            unit:"元",
            count:Math.floor(data)
        }
    }
    return {
        unit:"万元",
        count:Math.floor(data/10000)
    }
}

